@@ -6,7 +6,7 @@ use Mojo::JSON;
 use Mojo::Util 'deprecated';
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 sub EXCEPTION { +{errors => [{message => 'Internal server error.', path => '/'}], status => 500} }
 sub NOT_FOUND { +{errors => [{message => 'Not found.',             path => '/'}], status => 404} }
@@ -60,26 +60,32 @@ sub _add_routes {
 
   for my $path (sort { length $a <=> length $b } keys %$paths) {
     next if $path =~ $X_RE;
+    my @parameters = @{$paths->{$path}{parameters} || []};
+    my $route_path = $path;
     my $has_options;
 
     for my $http_method (keys %{$paths->{$path}}) {
-      next if $http_method =~ $X_RE;
+      next if $http_method =~ $X_RE or $http_method eq 'parameters';
       my $op_spec = $paths->{$path}{$http_method};
       my $name    = $op_spec->{'x-mojo-name'} || $op_spec->{operationId};
       my $to      = $op_spec->{'x-mojo-to'};
       my $endpoint;
 
       $has_options = 1 if lc $http_method eq 'options';
+      $route_path = _route_path($path, $op_spec);
 
       die qq([OpenAPI] operationId "$op_spec->{operationId}" is not unique)
         if $op_spec->{operationId} and $uniq{o}{$op_spec->{operationId}}++;
       die qq([OpenAPI] Route name "$name" is not unique.) if $name and $uniq{r}{$name}++;
 
+      if (@parameters) {
+        $op_spec->{parameters} = [@parameters, @{$op_spec->{parameters} || []}];
+      }
       if ($name and $endpoint = $route->root->find($name)) {
         $route->add_child($endpoint);
       }
       if (!$endpoint) {
-        $endpoint = $route->$http_method(_route_path($path, $op_spec));
+        $endpoint = $route->$http_method($route_path);
         $endpoint->name("$route_prefix$name") if $name;
       }
 
@@ -89,7 +95,7 @@ sub _add_routes {
     }
 
     unless ($has_options) {
-      $route->options($path => sub { _render_route_spec($_[0], $path) });
+      $route->options($route_path => sub { _render_route_spec($_[0], $path) });
     }
   }
 }
